@@ -1091,7 +1091,6 @@ picasa_post_add_tags (http_session_t session,
 	if(first == TRUE) {
 	  tag_str = g_string_new (sharing_tag_get_word (tag));
 	  first = FALSE;
-	  tags = tag_str->str;
 	} else {
 	  g_string_append (tag_str, ",");
 	  g_string_append (tag_str, sharing_tag_get_word (tag));
@@ -1156,6 +1155,8 @@ picasa_post_add_tags (http_session_t session,
     
   }
 
+  if (tag_str != NULL) { tags = tag_str->str; }
+
   /* if tags or coordinates to update */
   if (tags != NULL || res.msg != NULL) {
     ULOG_DEBUG_L ("%s: trying to update media entry", fn);
